==> igniteui-react-charts-16.4.1.tgz: package/ES5/PriceChannelOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { Type, Number_$type, typeCast, runOn, markType, Point_$type, fromEnum } from "igniteui-react-core/ES5/type";
import { CategoryFrame } from "./CategoryFrame";
import { Series } from "./Series";
import { MathUtil } from "igniteui-react-core/ES5/MathUtil";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core/ES5/Polyline";
import { Polygon } from "igniteui-react-core/ES5/Polygon";
import { RangeValueList } from "./RangeValueList";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { truncate, isNaN_, isInfinity } from "igniteui-react-core/ES5/number";
import { Flattener } from "igniteui-react-core/ES5/Flattener";
var PriceChannelOverlay = /** @class */ (function (_super) {
    tslib_1.__extends(PriceChannelOverlay, _super);
    function PriceChannelOverlay() {
        var _this = _super.call(this) || this;
        _this.pg = new List$1(Number_$type, 0);
        _this.pf = new List$1(Number_$type, 0);
        _this.ab = PriceChannelOverlay.$;
        _this.l2 = new CategoryFrame(3);
        _this.l4 = new CategoryFrame(3);
        _this.l1 = new CategoryFrame(3);
        return _this;
    }
    PriceChannelOverlay.prototype.ir = function (a, b, c, d) {
        switch (b) {
            case "HighColumn":
            case "LowColumn":
                this.o9 = false;
                break;
        }
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case PriceChannelOverlay.$$p[0]:
                this.o9 = false;
                this.i4(false);
                break;
        }
    };
    PriceChannelOverlay.prototype.du = function (a, b, c) {
        var d = _super.prototype.du.call(this, a, b, c);
        if (this.mp == null || this.mr == null) {
            d = false;
        }
        return d;
    };
    PriceChannelOverlay.prototype.pa = function () {
        this.pg.clear();
        this.pf.clear();
        var a = truncate(MathUtil.b(this.ph, 0, this.bz.count));
        var b = Math.min(this.mp.count, this.mr.count);
        var c = this.nj(this.mp);
        var d = this.nj(this.mr);
        for (var e = 0; e < b; e++) {
            var f = Math.min(a, e);
            var g = -1.7976931348623157E+308;
            var h = 1.7976931348623157E+308;
            for (var i = 0; i < f; i++) {
                if (!isNaN_(c.item(e - i))) {
                    g = Math.max(g, c.item(e - i));
                }
                if (!isNaN_(d.item(e - i))) {
                    h = Math.min(h, d.item(e - i));
                }
            }
            if (e == 0) {
                h = d.item(0);
                g = c.item(0);
            }
            this.pg.add(g);
            this.pf.add(h);
        }
        return true;
    };
    PriceChannelOverlay.prototype.oq = function (a, b) {
        _super.prototype.oq.call(this, a, b);
        var c = b.bq;
        var d = b.bp;
        var e = this.getEffectiveViewport1(b);
        var f = new ScalerParams(0, c, d, this.lz.b8, e);
        var g = new ScalerParams(0, c, d, this.mk.b8, e);
        g.b = this.ed();
        var h = this.lz;
        var i = this.mk;
        a.f.clear();
        a.m.clear();
        a.p.clear();
        var j = 0;
        var k = typeCast(ISortingAxis_$type, this.lz);
        if (k != null && k.i$b.count != this.bz.count) {
            return;
        }
        j = this.nq(c, d, e);
        if (!this.o9) {
            this.o9 = this.pa();
        }
        g.b = this.ed();
        var l = this.lz.dw(2, f) - this.lz.dw(1, f);
        for (var m = b.bs.c; m <= b.bs.d; ++m) {
            var n = void 0;
            if (k == null) {
                n = b.bs.getBucket(m);
            }
            else {
                var o = k.i$b._inner[m];
                var p = k.i$d(o);
                var q = this.pg._inner[m];
                var r = this.pf._inner[m];
                var s = q;
                var t = r;
                var u = p;
                while (m < b.bs.d) {
                    o = k.i$b._inner[m + 1];
                    u = k.i$d(o);
                    if (u - p > l) {
                        break;
                    }
                    m++;
                    s = Math.max(q, this.pg._inner[m]);
                    t = Math.min(r, this.pf._inner[m]);
                }
                if (!isInfinity(t) && !isInfinity(s)) {
                    var v = NaN;
                    if (!isNaN_(p)) {
                        v = this.lz.dt(p, f);
                    }
                    n = [v, t, s];
                }
                else {
                    n = [NaN, NaN, NaN];
                }
            }
            var w = Math.max(1, l);
            if (!isNaN_(n[0]) && m * w >= this.pb) {
                if (this.lz != null && typeCast(ISortingAxis_$type, this.lz) !== null) {
                    n[0] = n[0] + j;
                }
                else {
                    n[0] = h.dt(n[0], f) + j;
                }
                n[1] = i.dt(n[1], g);
                n[2] = i.dt(n[2], g);
                a.f.add(n);
            }
        }
    };
    PriceChannelOverlay.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        if (c != null) {
            c.bz();
        }
    };
    PriceChannelOverlay.prototype.os = function (a, b) {
        _super.prototype.os.call(this, a, b);
        var c = typeCast(PriceChannelOverlayView.$, b);
        if (c == null) {
            return;
        }
        var d = this.getEffectiveViewport1(b);
        if (b.bv(a)) {
            c.bz();
            var e_1 = a.f.count;
            var f = function (g) { return a.f._inner[g][0]; };
            var g = function (h) { return a.f._inner[e_1 - 1 - h][0]; };
            var h = function (i) { return a.f._inner[i][1]; };
            var i = function (j) { return a.f._inner[e_1 - 1 - j][2]; };
            c.b0(e_1, f, g, h, i);
            b.bx(a);
        }
        this.l7.x(this, this.m7(), this.lz, runOn(this, this.lr), this.nw(b), this.ny(b));
        var j = false;
        var k = this.l7.c;
        var l = a.f;
        var m = this.bz.count;
        if (k != null) {
            j = true;
        }
        if (j) {
            var n = new ScalerParams(0, b.bq, b.bp, this.lz.b8, d);
            this.op(l, -1, m, this.lz, n, b.n);
        }
        var o = c.b6;
        var p = c.b7;
        var q = c.b2;
        this.l7.ae(o, true, false, true, true);
        this.l7.ae(p, true, false, true, true);
        this.l7.ae(q, false, true, false, false);
        q._opacity = this.l7.i * this.d2;
    };
    PriceChannelOverlay.prototype.bf = function () {
        return new PriceChannelOverlayView(this);
    };
    PriceChannelOverlay.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.pe = typeCast(PriceChannelOverlayView.$, a);
    };
    PriceChannelOverlay.prototype.ej = function (a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.bi);
        var e = new ScalerParams(0, this.bs.ml, this.bi.bp, this.lz.b8, d);
        var f = this.nq(this.bs.ml, this.bi.bp, d);
        return this.el(new RangeValueList(this.pg, this.pf), a, this.lz, e, f, runOn(this, this.np), b, c);
    };
    PriceChannelOverlay.prototype.e8 = function (a, b) {
        if (this.pg == null || this.pf == null) {
            return _super.prototype.e8.call(this, a, b);
        }
        return this.e9(a, b, this.lz, runOn(this, this.np), new RangeValueList(this.pg, this.pf));
    };
    PriceChannelOverlay.prototype.fa = function (a, b) {
        if (this.pg == null || this.pf == null) {
            return _super.prototype.fa.call(this, a, b);
        }
        return this.fb(a, b, this.lz, runOn(this, this.np), new RangeValueList(this.pg, this.pf));
    };
    PriceChannelOverlay.prototype.ed = function () {
        return Series.ee(this.pf, null);
    };
    PriceChannelOverlay.$t = markType(PriceChannelOverlay, 'PriceChannelOverlay', FinancialOverlay.$);
    return PriceChannelOverlay;
}(FinancialOverlay));
export { PriceChannelOverlay };
Type.dep(DependencyProperty, PropertyMetadata, PriceChannelOverlay, 'raisePropertyChanged', ['Period:ph:pj', [1, 14]]);
var PriceChannelBucketCalculator = /** @class */ (function (_super) {
    tslib_1.__extends(PriceChannelBucketCalculator, _super);
    function PriceChannelBucketCalculator(a) {
        var _this = _super.call(this, a) || this;
        _this.f = null;
        _this.f = a;
        return _this;
    }
    PriceChannelBucketCalculator.prototype.getBucket = function (a) {
        var b = a * this.b;
        var c = Math.min(b + this.b - 1, this.a.bu.bz.count - 1);
        if (b <= c) {
            var d = -1.7976931348623157E+308;
            var e = 1.7976931348623157E+308;
            var f = 0;
            for (var g = b; g <= c; ++g) {
                if (!isNaN_(this.f.by.pg._inner[g]) && !isNaN_(this.f.by.pf._inner[g])) {
                    d = Math.max(d, this.f.by.pg._inner[g]);
                    e = Math.min(e, this.f.by.pf._inner[g]);
                    ++f;
                }
            }
            if (f > 0 && e != 1.7976931348623157E+308 && d != -1.7976931348623157E+308) {
                return [0.5 * (b + c), e, d];
            }
        }
        return [NaN, NaN, NaN];
    };
    PriceChannelBucketCalculator.$t = markType(PriceChannelBucketCalculator, 'PriceChannelBucketCalculator', FinancialBucketCalculator.$);
    return PriceChannelBucketCalculator;
}(FinancialBucketCalculator));
export { PriceChannelBucketCalculator };
var PriceChannelOverlayView = /** @class */ (function (_super) {
    tslib_1.__extends(PriceChannelOverlayView, _super);
    function PriceChannelOverlayView(a) {
        var _this = _super.call(this, a) || this;
        _this.b3 = new Polygon();
        _this.b8 = new Polyline();
        _this.b9 = new Polyline();
        _this.by = null;
        _this.b1 = new Polygon();
        _this.b4 = new Polyline();
        _this.b5 = new Polyline();
        _this.by = a;
        return _this;
    }
    Object.defineProperty(PriceChannelOverlayView.prototype, "b2", {
        get: function () {
            return this.b3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PriceChannelOverlayView.prototype, "b6", {
        get: function () {
            return this.b8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PriceChannelOverlayView.prototype, "b7", {
        get: function () {
            return this.b9;
        },
        enumerable: true,
        configurable: true
    });
    PriceChannelOverlayView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        if (!this.n) {
            this.e.bj = 1;
        }
    };
    PriceChannelOverlayView.prototype.bt = function () {
        return new PriceChannelBucketCalculator(this);
    };
    PriceChannelOverlayView.prototype.bz = function () {
        this.b3.aj.clear();
        this.b8.aj.clear();
        this.b9.aj.clear();
        this.an();
    };
    PriceChannelOverlayView.prototype.b0 = function (a, b, c, d, e) {
        var e_2, _a, e_3, _b;
        try {
            for (var _c = tslib_1.__values(fromEnum(Flattener.d(a, b, d, this.e.eq))), _d = _c.next(); !_d.done; _d = _c.next()) {
                var f = _d.value;
                this.b3.aj.add({ $type: Point_$type, x: b(f), y: d(f) });
                this.b8.aj.add({ $type: Point_$type, x: b(f), y: d(f) });
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
            }
            finally { if (e_2) throw e_2.error; }
        }
        try {
            for (var _e = tslib_1.__values(fromEnum(Flattener.d(a, c, e, this.e.eq))), _f = _e.next(); !_f.done; _f = _e.next()) {
                var g = _f.value;
                this.b3.aj.add({ $type: Point_$type, x: c(g), y: e(g) });
                this.b9.aj.add({ $type: Point_$type, x: c(g), y: e(g) });
            }
        }
        catch (e_3_1) { e_3 = { error: e_3_1 }; }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
            }
            finally { if (e_3) throw e_3.error; }
        }
        this.an();
    };
    PriceChannelOverlayView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        this.b1.aj = this.b3.aj;
        this.b4.aj = this.b8.aj;
        this.b5.aj = this.b9.aj;
        var a = this.bk();
        this.b1._fill = a;
        this.b1._opacity = 1;
        this.b4._stroke = a;
        this.b4.ac = this.e.eu + 3;
        this.b5._stroke = a;
        this.b5.ac = this.e.eu + 3;
    };
    PriceChannelOverlayView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.b1);
                a.u(this.b4);
                a.u(this.b5);
            }
            else {
                a.t(this.b3);
                a.u(this.b8);
                a.u(this.b9);
            }
        }
    };
    PriceChannelOverlayView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPolygonData(a, this.b3, "fill", ["Fill"]);
        this.e.a2.exportPolylineData(a, this.b8, "bottom", ["Lower", "Main"]);
        this.e.a2.exportPolylineData(a, this.b9, "top", ["Upper"]);
    };
    PriceChannelOverlayView.$t = markType(PriceChannelOverlayView, 'PriceChannelOverlayView', FinancialSeriesView.$);
    return PriceChannelOverlayView;
}(FinancialSeriesView));
export { PriceChannelOverlayView };
/*<BeginStatics Name="Infragistics.Controls.Charts.PriceChannelOverlay" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.PriceChannelOverlay" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES5/PriceChannelOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { Type, Number_$type, typeCast, runOn, markType, Point_$type, fromEnum } from "igniteui-react-core/ES5/type";
import { CategoryFrame } from "./CategoryFrame";
import { Series } from "./Series";
import { MathUtil } from "igniteui-react-core/ES5/MathUtil";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core/ES5/Polyline";
import { Polygon } from "igniteui-react-core/ES5/Polygon";
import { RangeValueList } from "./RangeValueList";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { truncate, isNaN_, isInfinity } from "igniteui-react-core/ES5/number";
import { Flattener } from "igniteui-react-core/ES5/Flattener";
var PriceChannelOverlay = /** @class */ (function (_super) {
    tslib_1.__extends(PriceChannelOverlay, _super);
    function PriceChannelOverlay() {
        var _this = _super.call(this) || this;
        _this.pg = new List$1(Number_$type, 0);
        _this.pf = new List$1(Number_$type, 0);
        _this.ab = PriceChannelOverlay.$;
        _this.l2 = new CategoryFrame(3);
        _this.l4 = new CategoryFrame(3);
        _this.l1 = new CategoryFrame(3);
        return _this;
    }
    PriceChannelOverlay.prototype.ir = function (a, b, c, d) {
        switch (b) {
            case "HighColumn":
            case "LowColumn":
                this.o9 = false;
                break;
        }
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case PriceChannelOverlay.$$p[0]:
                this.o9 = false;
                this.i4(false);
                break;
        }
    };
    PriceChannelOverlay.prototype.du = function (a, b, c) {
        var d = _super.prototype.du.call(this, a, b, c);
        if (this.mp == null || this.mr == null) {
            d = false;
        }
        return d;
    };
    PriceChannelOverlay.prototype.pa = function () {
        this.pg.clear();
        this.pf.clear();
        var a = truncate(MathUtil.b(this.ph, 0, this.bz.count));
        var b = Math.min(this.mp.count, this.mr.count);
        var c = this.nj(this.mp);
        var d = this.nj(this.mr);
        for (var e = 0; e < b; e++) {
            var f = Math.min(a, e);
            var g = -1.7976931348623157E+308;
            var h = 1.7976931348623157E+308;
            for (var i = 0; i < f; i++) {
                if (!isNaN_(c.item(e - i))) {
                    g = Math.max(g, c.item(e - i));
                }
                if (!isNaN_(d.item(e - i))) {
                    h = Math.min(h, d.item(e - i));
                }
            }
            if (e == 0) {
                h = d.item(0);
                g = c.item(0);
            }
            this.pg.add(g);
            this.pf.add(h);
        }
        return true;
    };
    PriceChannelOverlay.prototype.oq = function (a, b) {
        _super.prototype.oq.call(this, a, b);
        var c = b.bs;
        var d = b.br;
        var e = this.getEffectiveViewport1(b);
        var f = new ScalerParams(0, c, d, this.lz.b8, e);
        var g = new ScalerParams(0, c, d, this.mk.b8, e);
        g.b = this.ed();
        var h = this.lz;
        var i = this.mk;
        a.f.clear();
        a.m.clear();
        a.p.clear();
        var j = 0;
        var k = typeCast(ISortingAxis_$type, this.lz);
        if (k != null && k.i$b.count != this.bz.count) {
            return;
        }
        j = this.nq(c, d, e);
        if (!this.o9) {
            this.o9 = this.pa();
        }
        g.b = this.ed();
        var l = this.lz.dw(2, f) - this.lz.dw(1, f);
        for (var m = b.bu.c; m <= b.bu.d; ++m) {
            var n = void 0;
            if (k == null) {
                n = b.bu.getBucket(m);
            }
            else {
                var o = k.i$b._inner[m];
                var p = k.i$d(o);
                var q = this.pg._inner[m];
                var r = this.pf._inner[m];
                var s = q;
                var t = r;
                var u = p;
                while (m < b.bu.d) {
                    o = k.i$b._inner[m + 1];
                    u = k.i$d(o);
                    if (u - p > l) {
                        break;
                    }
                    m++;
                    s = Math.max(q, this.pg._inner[m]);
                    t = Math.min(r, this.pf._inner[m]);
                }
                if (!isInfinity(t) && !isInfinity(s)) {
                    var v = NaN;
                    if (!isNaN_(p)) {
                        v = this.lz.dt(p, f);
                    }
                    n = [v, t, s];
                }
                else {
                    n = [NaN, NaN, NaN];
                }
            }
            var w = Math.max(1, l);
            if (!isNaN_(n[0]) && m * w >= this.pb) {
                if (this.lz != null && typeCast(ISortingAxis_$type, this.lz) !== null) {
                    n[0] = n[0] + j;
                }
                else {
                    n[0] = h.dt(n[0], f) + j;
                }
                n[1] = i.dt(n[1], g);
                n[2] = i.dt(n[2], g);
                a.f.add(n);
            }
        }
    };
    PriceChannelOverlay.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        if (c != null) {
            c.b1();
        }
    };
    PriceChannelOverlay.prototype.os = function (a, b) {
        _super.prototype.os.call(this, a, b);
        var c = typeCast(PriceChannelOverlayView.$, b);
        if (c == null) {
            return;
        }
        var d = this.getEffectiveViewport1(b);
        if (b.bx(a)) {
            c.b1();
            var e_1 = a.f.count;
            var f = function (g) { return a.f._inner[g][0]; };
            var g = function (h) { return a.f._inner[e_1 - 1 - h][0]; };
            var h = function (i) { return a.f._inner[i][1]; };
            var i = function (j) { return a.f._inner[e_1 - 1 - j][2]; };
            c.b2(e_1, f, g, h, i);
            b.bz(a);
        }
        this.l7.x(this, this.m7(), this.lz, runOn(this, this.lr), this.nw(b), this.ny(b));
        var j = false;
        var k = this.l7.c;
        var l = a.f;
        var m = this.bz.count;
        if (k != null) {
            j = true;
        }
        if (j) {
            var n = new ScalerParams(0, b.bs, b.br, this.lz.b8, d);
            this.op(l, -1, m, this.lz, n, b.n);
        }
        var o = c.b8;
        var p = c.b9;
        var q = c.b4;
        this.l7.ae(o, true, false, true, true);
        this.l7.ae(p, true, false, true, true);
        this.l7.ae(q, false, true, false, false);
        q._opacity = this.l7.i * this.d2;
    };
    PriceChannelOverlay.prototype.bf = function () {
        return new PriceChannelOverlayView(this);
    };
    PriceChannelOverlay.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.pe = typeCast(PriceChannelOverlayView.$, a);
    };
    PriceChannelOverlay.prototype.ej = function (a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        var d = this.getEffectiveViewport1(this.bi);
        var e = new ScalerParams(0, this.bs.mn, this.bi.br, this.lz.b8, d);
        var f = this.nq(this.bs.mn, this.bi.br, d);
        return this.el(new RangeValueList(this.pg, this.pf), a, this.lz, e, f, runOn(this, this.np), b, c);
    };
    PriceChannelOverlay.prototype.e8 = function (a, b) {
        if (this.pg == null || this.pf == null) {
            return _super.prototype.e8.call(this, a, b);
        }
        return this.e9(a, b, this.lz, runOn(this, this.np), new RangeValueList(this.pg, this.pf));
    };
    PriceChannelOverlay.prototype.fa = function (a, b) {
        if (this.pg == null || this.pf == null) {
            return _super.prototype.fa.call(this, a, b);
        }
        return this.fb(a, b, this.lz, runOn(this, this.np), new RangeValueList(this.pg, this.pf));
    };
    PriceChannelOverlay.prototype.ed = function () {
        return Series.ee(this.pf, null);
    };
    PriceChannelOverlay.$t = markType(PriceChannelOverlay, 'PriceChannelOverlay', FinancialOverlay.$);
    return PriceChannelOverlay;
}(FinancialOverlay));
export { PriceChannelOverlay };
Type.dep(DependencyProperty, PropertyMetadata, PriceChannelOverlay, 'raisePropertyChanged', ['Period:ph:pj', [1, 14]]);
var PriceChannelBucketCalculator = /** @class */ (function (_super) {
    tslib_1.__extends(PriceChannelBucketCalculator, _super);
    function PriceChannelBucketCalculator(a) {
        var _this = _super.call(this, a) || this;
        _this.f = null;
        _this.f = a;
        return _this;
    }
    PriceChannelBucketCalculator.prototype.getBucket = function (a) {
        var b = a * this.b;
        var c = Math.min(b + this.b - 1, this.a.bw.bz.count - 1);
        if (b <= c) {
            var d = -1.7976931348623157E+308;
            var e = 1.7976931348623157E+308;
            var f = 0;
            for (var g = b; g <= c; ++g) {
                if (!isNaN_(this.f.b0.pg._inner[g]) && !isNaN_(this.f.b0.pf._inner[g])) {
                    d = Math.max(d, this.f.b0.pg._inner[g]);
                    e = Math.min(e, this.f.b0.pf._inner[g]);
                    ++f;
                }
            }
            if (f > 0 && e != 1.7976931348623157E+308 && d != -1.7976931348623157E+308) {
                return [0.5 * (b + c), e, d];
            }
        }
        return [NaN, NaN, NaN];
    };
    PriceChannelBucketCalculator.$t = markType(PriceChannelBucketCalculator, 'PriceChannelBucketCalculator', FinancialBucketCalculator.$);
    return PriceChannelBucketCalculator;
}(FinancialBucketCalculator));
export { PriceChannelBucketCalculator };
var PriceChannelOverlayView = /** @class */ (function (_super) {
    tslib_1.__extends(PriceChannelOverlayView, _super);
    function PriceChannelOverlayView(a) {
        var _this = _super.call(this, a) || this;
        _this.b5 = new Polygon();
        _this.ca = new Polyline();
        _this.cb = new Polyline();
        _this.b0 = null;
        _this.b3 = new Polygon();
        _this.b6 = new Polyline();
        _this.b7 = new Polyline();
        _this.b0 = a;
        return _this;
    }
    Object.defineProperty(PriceChannelOverlayView.prototype, "b4", {
        get: function () {
            return this.b5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PriceChannelOverlayView.prototype, "b8", {
        get: function () {
            return this.ca;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PriceChannelOverlayView.prototype, "b9", {
        get: function () {
            return this.cb;
        },
        enumerable: true,
        configurable: true
    });
    PriceChannelOverlayView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        if (!this.n) {
            this.e.bj = 1;
        }
    };
    PriceChannelOverlayView.prototype.bv = function () {
        return new PriceChannelBucketCalculator(this);
    };
    PriceChannelOverlayView.prototype.b1 = function () {
        this.b5.aj.clear();
        this.ca.aj.clear();
        this.cb.aj.clear();
        this.an();
    };
    PriceChannelOverlayView.prototype.b2 = function (a, b, c, d, e) {
        var e_2, _a, e_3, _b;
        try {
            for (var _c = tslib_1.__values(fromEnum(Flattener.d(a, b, d, this.e.eq))), _d = _c.next(); !_d.done; _d = _c.next()) {
                var f = _d.value;
                this.b5.aj.add({ $type: Point_$type, x: b(f), y: d(f) });
                this.ca.aj.add({ $type: Point_$type, x: b(f), y: d(f) });
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
            }
            finally { if (e_2) throw e_2.error; }
        }
        try {
            for (var _e = tslib_1.__values(fromEnum(Flattener.d(a, c, e, this.e.eq))), _f = _e.next(); !_f.done; _f = _e.next()) {
                var g = _f.value;
                this.b5.aj.add({ $type: Point_$type, x: c(g), y: e(g) });
                this.cb.aj.add({ $type: Point_$type, x: c(g), y: e(g) });
            }
        }
        catch (e_3_1) { e_3 = { error: e_3_1 }; }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
            }
            finally { if (e_3) throw e_3.error; }
        }
        this.an();
    };
    PriceChannelOverlayView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        this.b3.aj = this.b5.aj;
        this.b6.aj = this.ca.aj;
        this.b7.aj = this.cb.aj;
        var a = this.bl();
        this.b3._fill = a;
        this.b3._opacity = 1;
        this.b6._stroke = a;
        this.b6.ac = this.e.eu + 3;
        this.b7._stroke = a;
        this.b7.ac = this.e.eu + 3;
    };
    PriceChannelOverlayView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.b3);
                a.u(this.b6);
                a.u(this.b7);
            }
            else {
                a.t(this.b5);
                a.u(this.ca);
                a.u(this.cb);
            }
        }
    };
    PriceChannelOverlayView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPolygonData(a, this.b5, "fill", ["Fill"]);
        this.e.a2.exportPolylineData(a, this.ca, "bottom", ["Lower", "Main"]);
        this.e.a2.exportPolylineData(a, this.cb, "top", ["Upper"]);
    };
    PriceChannelOverlayView.$t = markType(PriceChannelOverlayView, 'PriceChannelOverlayView', FinancialSeriesView.$);
    return PriceChannelOverlayView;
}(FinancialSeriesView));
export { PriceChannelOverlayView };
